carousel_slider_plus library

Classes

CarouselControllerPlus
CarouselOptions
CarouselSlider
A carousel slider widget.

Typedefs

ExtendedIndexedWidgetBuilder = Widget Function(BuildContext context, int index, int realIndex)
A function that creates a widget for a given index This is useful for when you want to create the items on demand