ExtendedIndexedWidgetBuilder typedef
ExtendedIndexedWidgetBuilder =
Widget Function(BuildContext context, int index, int realIndex)
A function that creates a widget for a given index This is useful for when you want to create the items on demand
Implementation
typedef ExtendedIndexedWidgetBuilder = Widget Function(
BuildContext context,
int index,
int realIndex,
);